@@ -335,7 +335,7 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
         self.members: dict[str, Object | Alias] = {}
         self.labels: set[str] = set()
         self.imports: dict[str, str] = {}
-        self.exports: set[str] | None = None
+        self.exports: set[str] | list[str | Name] | None = None
         self.aliases: dict[str, Alias] = {}
         self.runtime: bool = runtime
         self._lines_collection: LinesCollection | None = lines_collection
@@ -348,6 +348,9 @@ class Object(GetMembersMixin, SetMembersMixin, ObjectAliasMixin):
     def __repr__(self) -> str:
         return f"<{self.__class__.__name__}({self.name!r}, {self.lineno!r}, {self.endlineno!r})>"
 
+    def __bool__(self) -> bool:
+        return True
+
     def __len__(self) -> int:
         return len(self.members) + sum(len(member) for member in self.members.values())
 
@@ -1129,6 +1132,18 @@ class Class(Object):
         self.bases: list[Name | Expression | str] = bases or []
         self.decorators: list[Decorator] = decorators or []
 
+    @property
+    def parameters(self) -> Parameters:
+        """Return the parameters of this class' `__init__` method, if any.
+
+        Returns:
+            The parameters containter.
+        """
+        try:
+            return self.members["__init__"].parameters  # type: ignore[union-attr]
+        except KeyError:
+            return Parameters()
+
     def as_dict(self, **kwargs: Any) -> dict[str, Any]:  # type: ignore[override]
         """Return this class' data as a dictionary.
 
